@@ -344,14 +344,20 @@ impl Kubectl {
         Ok(())
     }
 
-    pub(crate) async fn install_statehub_cluster(&self, namespace: &str) -> anyhow::Result<()> {
+    pub(crate) async fn install_statehub_cluster(
+        &self,
+        namespace: &str,
+        install_state_crd: bool,
+    ) -> anyhow::Result<()> {
         let crd = self.create_statehub_cluster_crd().await?;
         log::debug!("Created StatehubCluster CRD: {:#?}", crd);
         let cluster = self.create_statehub_cluster(namespace).await?;
         log::debug!("Created StatehubCluster: {:#?}", cluster);
 
-        let crd = self.create_statehub_state_crd().await?;
-        log::debug!("Created State CRD: {:#?}", crd);
+        if install_state_crd {
+            let crd = self.create_statehub_state_crd().await?;
+            log::debug!("Created State CRD: {:#?}", crd);
+        }
 
         let client = self.get_client().await?;
         let statehub_kubectl = statehub_cluster_operator::cluster::Kubectl::new(client);
