@@ -126,7 +126,8 @@ enum Command {
         #[structopt(
             help = "Non-interactive cluster registration, automatic defaults apply",
             long,
-            visible_aliases = &["yes", "y"],
+            short = "y",
+            visible_alias = "yes"
         )]
         non_interactive: bool,
 
@@ -156,6 +157,9 @@ enum Command {
         )]
         no_state: bool,
 
+        #[structopt(help = "Skip installing state CRD", long)]
+        no_state_crd: bool,
+
         #[structopt(
             help = "Skip setting up default storage class",
             long,
@@ -579,6 +583,7 @@ impl Cli {
                 contexts,
                 states,
                 no_state,
+                no_state_crd,
                 no_default_storage_class,
                 default_storage_class,
                 no_state_owner,
@@ -606,6 +611,7 @@ impl Cli {
                 };
 
                 let states = if no_state { None } else { Some(states) };
+                let install_state_crd = !no_state_crd;
                 let claim_unowned_states = !no_state_owner;
 
                 let helm = k8s::Helm::new(skip_helm);
@@ -620,6 +626,7 @@ impl Cli {
                     default_state,
                     claim_unowned_states,
                     cleanup_grace,
+                    install_state_crd,
                     azure,
                 );
                 if interactive {
@@ -919,7 +926,7 @@ impl StateHub {
         }
 
         for (locations, kubectl) in clusters {
-            self.register_cluster_helper(kubectl, &locations, register_cluster.clone())
+            self.register_cluster_helper(kubectl, &locations, &register_cluster)
                 .await?;
         }
 
@@ -1213,7 +1220,7 @@ impl StateHub {
         namespace: String,
     ) -> anyhow::Result<()> {
         for kubectl in kubectls {
-            kubectl.install_statehub_cluster(&namespace).await?;
+            kubectl.install_statehub_cluster(&namespace, false).await?;
         }
 
         Ok(())
